import { LayoutProps } from "$fresh/server.ts";
import { resources } from "@lib/resources.ts";
import { CSS, KATEX_CSS } from "https://deno.land/x/gfm@0.2.5/mod.ts";
import { Head } from "$fresh/runtime.ts";
import { Emoji } from "@components/Emoji.tsx";

export default function MyLayout({ Component, url }: LayoutProps) {
  return (
    <div
      class="md:grid mx-auto"
      style={{ gridTemplateColumns: "200px 1fr", maxWidth: "1024px" }}
    >
      <Head>
        <style>{CSS}</style>
        <style>{KATEX_CSS}</style>
      </Head>
      <aside class="p-4 hidden md:block">
        <nav class="min-h-fit rounded-3xl p-3 grid gap-3 fixed t-0">
          {Object.values(resources).map((m) => {
            return (
              <a
                href={m.link}
                class={`flex items-center gap-2  ${
                  m.link === url.pathname ? "bg-white text-black" : "text-white"
                } p-3 text-xl w-full rounded-2xl`}
              >
                {<Emoji class="w-6 h-6" name={m.emoji} />} {m.name}
              </a>
            );
          })}
        </nav>
      </aside>
      <main
        class="py-5"
        style={{ fontFamily: "Work Sans" }}
      >
        <Component />
      </main>
    </div>
  );
}
